@@ -9,7 +9,7 @@ function (x,...) {
   cat ("The analysis was performed on ", nrow(res.tepDICA$fi),
        "individuals, described by", nrow(res.tepDICA$fj), "variables\n")
   cat("*The results are available in the following objects:\n\n")
-  res <- array("", c(20, 2), list(1:20, c("name", "description")))
+  res <- array("", c(23, 2), list(1:23, c("name", "description")))
   
   res[1,] <- c("$fi","Factor scores of the groups")
   res[2,] <- c("$di","Squared distances of the groups")
@@ -19,18 +19,21 @@ function (x,...) {
   res[6,] <- c("$dj","square distances of the columns")
   res[7,] <- c("$cj","Contributions for the columns")
   res[8,] <- c("$rj", "Cosines of the columns")
-  res[9,] <- c("$t","Explained Variance")
-  res[10,] <- c("$eigs","Eigenvalues")  
-  res[11,] <- c("$M","masses")
-  res[12,] <- c("$W","weights")
-  res[13,] <- c("$pdq","GSVD data")    
-  res[14,] <- c("$X","X matrix to decompose")    
-  res[15,] <- c("$hellinger","a boolean. TRUE if Hellinger distance was used")        
-  res[16,] <- c("$symmetric","a boolean. TRUE if symmetric scores used for biplot.")
-  res[17,] <- c("$fii","Factor scores of the individuals")
-  res[18,] <- c("$dii","Squared distances of the individuals")
-  res[19,] <- c("$rii", "Cosines of the individuals")
-  res[20,] <- c("$assign","Information for assignment of individuals to groups")
+  res[9,] <- c("$lx", "Latent variables of X (DATA)")
+  res[10,] <- c("$ly", "Latent variables of Y (DESIGN)")    
+  res[11,] <- c("$t","Explained Variance")
+  res[12,] <- c("$eigs","Eigenvalues")  
+  res[13,] <- c("$M","masses")
+  res[14,] <- c("$W","weights")
+  res[15,] <- c("$c","center")  
+  res[16,] <- c("$pdq","GSVD data")    
+  res[17,] <- c("$X","X matrix to decompose")    
+  res[18,] <- c("$hellinger","a boolean. TRUE if Hellinger distance was used")        
+  res[19,] <- c("$symmetric","a boolean. TRUE if symmetric scores used for biplot.")
+  res[20,] <- c("$fii","Factor scores of the individuals")
+  res[21,] <- c("$dii","Squared distances of the individuals")
+  res[22,] <- c("$rii", "Cosines of the individuals")
+  res[23,] <- c("$assign","Information for assignment of individuals to groups")
 
   
   
